@@ -18,6 +18,7 @@ Foundation; version 2 of the licence.
 #include <unistd.h>
 #include <stdlib.h>
 #include <string.h>
+#include <ctype.h>
 
 #include "callbacks.h"
 #include "interface.h"
@@ -192,28 +193,6 @@ on_artist_edited                    (GtkCellRendererText *cell,
         gtk_list_store_set(store, &iter, COL_TRACKARTIST, new_text, -1);
 }
 
-// lnr
-void
-on_genre_edited                    (GtkCellRendererText *cell,
-                                     gchar               *path_string,
-                                     gchar               *new_text,
-                                     gpointer             user_data)
-{
-    GtkListStore * store = GTK_LIST_STORE(gtk_tree_view_get_model(
-                    GTK_TREE_VIEW(lookup_widget(win_main, "tracklist"))));
-    GtkTreeIter iter;
-    
-    //trim_chars(new_text, BADCHARS);	//Commented out by mrpl
-    trim_whitespace(new_text);
-    
-    gtk_tree_model_get_iter_from_string(GTK_TREE_MODEL(store), &iter, path_string);
-    
-    if(new_text[0] == '\0')
-        gtk_list_store_set(store, &iter, COL_GENRE, "Unknown", -1);
-    else
-        gtk_list_store_set(store, &iter, COL_GENRE, new_text, -1);
-}
-
 void
 on_cancel_clicked                      (GtkButton       *button,
                                         gpointer         user_data)
@@ -349,6 +328,181 @@ on_prefs_show                          (GtkWidget       *widget,
     set_widgets_from_prefs(global_prefs);
 }
 
+
+void
+on_edit_capitalize_clicked (void)
+{
+    // "Capitalize Artists & Titles"
+
+    GtkTreeIter iter;
+    GtkListStore * store = GTK_LIST_STORE(gtk_tree_view_get_model(GTK_TREE_VIEW(lookup_widget(win_main, "tracklist"))));
+    if (store == NULL)
+        return;
+
+    gboolean rowsleft = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(store), &iter);
+    while (rowsleft)
+    {
+        int riptrack;
+        char * trackartist = NULL;
+        char * tracktitle = NULL;
+
+        gtk_tree_model_get(GTK_TREE_MODEL(store), &iter,
+            COL_RIPTRACK, &riptrack,
+            COL_TRACKARTIST, &trackartist,
+            COL_TRACKTITLE, &tracktitle,
+            -1);
+
+        if (riptrack)       // Only modify selected tracks
+        {
+            int start_of_word = 1;
+            for (char *cp = trackartist; *cp; ++cp)
+            {
+                if (isspace(*cp))
+                {
+                    start_of_word = 1;
+                }
+                else
+                if (start_of_word)
+                {
+                    if (islower(*cp))
+                        *cp = toupper(*cp);
+                    start_of_word = 0;
+                }
+            }
+
+            start_of_word = 1;
+            for (char *cp = tracktitle; *cp; ++cp)
+            {
+                if (isspace(*cp))
+                {
+                    start_of_word = 1;
+                }
+                else
+                if (start_of_word)
+                {
+                    if (islower(*cp))
+                        *cp = toupper(*cp);
+                    start_of_word = 0;
+                }
+            }
+
+            // Write modified values back into widgets
+            gtk_list_store_set(store, &iter,
+                COL_TRACKARTIST, trackartist,
+                COL_TRACKTITLE, tracktitle,
+                -1);
+        }
+
+        if (trackartist)
+            free (trackartist);
+        if (tracktitle)
+            free (tracktitle);
+
+        rowsleft = gtk_tree_model_iter_next(GTK_TREE_MODEL(store), &iter);
+    }
+}
+
+void
+on_edit_split_clicked (void)
+{
+    // "Split 'Artist/Title' in Title field"
+
+    GtkTreeIter iter;
+    GtkListStore * store = GTK_LIST_STORE(gtk_tree_view_get_model(GTK_TREE_VIEW(lookup_widget(win_main, "tracklist"))));
+    if (store == NULL)
+        return;
+
+    gboolean rowsleft = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(store), &iter);
+    while (rowsleft)
+    {
+        int riptrack;
+        char * trackartist = NULL;
+        char * tracktitle = NULL;
+
+        gtk_tree_model_get(GTK_TREE_MODEL(store), &iter,
+            COL_RIPTRACK, &riptrack,
+            COL_TRACKTITLE, &tracktitle,
+            -1);
+
+        if (riptrack)       // Only modify selected tracks
+        {
+            char *slash = strchr(tracktitle, '/');
+            if (slash != NULL)
+            {
+                // If slash is present, split Artist/Title
+                trackartist = strdup(tracktitle);
+                slash = strchr(trackartist, '/');
+                char *cp = slash + 1;
+                while (*cp && isspace(*cp))     // Remove space after slash
+                    ++cp;
+                strcpy(tracktitle, cp);
+                *slash = '\0';
+                cp = slash - 1;
+                while (cp >= trackartist && *cp && isspace(*cp))     // Remove space before slash
+                {
+                    *cp = '\0';
+                    cp--;
+				}
+				
+                // Write modified values back into widgets
+                gtk_list_store_set(store, &iter,
+                    COL_TRACKARTIST, trackartist,
+                    COL_TRACKTITLE, tracktitle,
+                    -1);
+            }
+        }
+		
+        if (trackartist)
+            free (trackartist);
+        if (tracktitle)
+            free (tracktitle);
+		
+        rowsleft = gtk_tree_model_iter_next(GTK_TREE_MODEL(store), &iter);
+    }
+}
+
+void
+on_edit_swap_clicked (void)
+{
+    // "Swap Artist <=> Title"
+
+    GtkTreeIter iter;
+    GtkListStore * store = GTK_LIST_STORE(gtk_tree_view_get_model(GTK_TREE_VIEW(lookup_widget(win_main, "tracklist"))));
+    if (store == NULL)
+        return;
+
+    gboolean rowsleft = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(store), &iter);
+    while (rowsleft)
+    {
+        int riptrack;
+        char * trackartist = NULL;
+        char * tracktitle = NULL;
+
+        gtk_tree_model_get(GTK_TREE_MODEL(store), &iter,
+            COL_RIPTRACK, &riptrack,
+            COL_TRACKARTIST, &trackartist,
+            COL_TRACKTITLE, &tracktitle,
+            -1);
+
+        if (riptrack)       // Only modify selected tracks
+        {
+            // Write swapped values back into widgets
+            gtk_list_store_set(store, &iter,
+                COL_TRACKARTIST, tracktitle,
+                COL_TRACKTITLE, trackartist,
+                -1);
+        }
+
+        if (trackartist)
+            free (trackartist);
+        if (tracktitle)
+            free (tracktitle);
+
+        rowsleft = gtk_tree_model_iter_next(GTK_TREE_MODEL(store), &iter);
+    }
+}
+
+
 void 
 on_press_f2                       (void)
 {
@@ -650,15 +804,6 @@ on_single_artist_toggled               (GtkToggleButton *togglebutton,
     gtk_tree_view_column_set_visible(col, !gtk_toggle_button_get_active(togglebutton));
 }
 
-// lnr
-void
-on_single_genre_toggled               (GtkToggleButton *togglebutton,
-                                        gpointer         user_data)
-{
-    GtkTreeViewColumn * col = gtk_tree_view_get_column(GTK_TREE_VIEW(tracklist), COL_GENRE );
-    gtk_tree_view_column_set_visible(col, !gtk_toggle_button_get_active(togglebutton));
-}
-
 void
 on_title_edited                    (GtkCellRendererText *cell,
                                     gchar               *path_string,
@@ -706,6 +851,24 @@ on_tracklist_mouse_click               (GtkWidget* treeView,
                          G_CALLBACK(on_deselect_all_click), NULL);
         gtk_menu_shell_append(GTK_MENU_SHELL(menu), menuItem);
         gtk_widget_show_all(menu);
+
+        menuItem = gtk_menu_item_new_with_label(_("Capitalize Artists & Titles"));
+        g_signal_connect(menuItem, "activate",
+                         G_CALLBACK(on_edit_capitalize_clicked), NULL);
+        gtk_menu_shell_append(GTK_MENU_SHELL(menu), menuItem);
+        gtk_widget_show_all(menu);
+
+        menuItem = gtk_menu_item_new_with_label(_("Split 'Artist/Title' in Title field"));
+        g_signal_connect(menuItem, "activate",
+                         G_CALLBACK(on_edit_split_clicked), NULL);
+        gtk_menu_shell_append(GTK_MENU_SHELL(menu), menuItem);
+        gtk_widget_show_all(menu);
+
+        menuItem = gtk_menu_item_new_with_label(_("Swap Artist <=> Title"));
+        g_signal_connect(menuItem, "activate",
+                         G_CALLBACK(on_edit_swap_clicked), NULL);
+        gtk_menu_shell_append(GTK_MENU_SHELL(menu), menuItem);
+        gtk_widget_show_all(menu);
         
         gtk_menu_popup(GTK_MENU(menu), NULL, NULL, NULL, NULL,
                        event->button, gdk_event_get_time((GdkEvent*)event));
