@@ -67,7 +67,6 @@ create_main (void)
     GtkWidget* statusLbl;
     GtkWidget *album_genre;			// lnr
     GtkWidget *genre_label;			// lnr
-    GtkWidget *single_genre;		// lnr
     
     main_win = gtk_window_new (GTK_WINDOW_TOPLEVEL);
     gtk_window_set_title (GTK_WINDOW (main_win), "Asunder");
@@ -175,12 +174,6 @@ create_main (void)
                       (GtkAttachOptions) (GTK_FILL),
                       (GtkAttachOptions) (0), 3, 0);
 
-    single_genre = gtk_check_button_new_with_mnemonic(_("Single Genre"));	// lnr
-    //~ gtk_widget_show( single_genre );
-    //~ gtk_table_attach( GTK_TABLE( table2 ), single_genre, 2, 3, 3, 4,
-                      //~ (GtkAttachOptions) ( GTK_FILL ),
-                      //~ (GtkAttachOptions) (0), 3, 0);
-                      
     GtkWidget* album_year = gtk_entry_new();
     gtk_widget_show(album_year);
     gtk_table_attach( GTK_TABLE( table2 ), album_year, 2, 3, 3, 4,
@@ -267,9 +260,6 @@ create_main (void)
     g_signal_connect ((gpointer) album_genre, "focus_out_event",					// lnr
                                         G_CALLBACK (on_album_genre_focus_out_event),
                                         NULL);
-    g_signal_connect ((gpointer) single_genre, "toggled",
-                                        G_CALLBACK (on_single_genre_toggled),
-                                        NULL);
     g_signal_connect ((gpointer) album_year, "focus_out_event",
                                         G_CALLBACK (on_year_focus_out_event),
                                         NULL);
@@ -322,7 +312,6 @@ create_main (void)
     GLADE_HOOKUP_OBJECT (main_win, statusLbl, "statusLbl");
     GLADE_HOOKUP_OBJECT (main_win, album_genre, "album_genre");			// lnr
     GLADE_HOOKUP_OBJECT (main_win, genre_label, "genre_label" );		// lnr
-    GLADE_HOOKUP_OBJECT (main_win, single_genre, "single_genre" );		// lnr
     GLADE_HOOKUP_OBJECT (main_win, album_year, "album_year");
     
     return main_win;
@@ -1298,7 +1287,6 @@ void disable_all_main_widgets(void)
     gtk_widget_set_sensitive(lookup_widget(win_main, "rip_button"), FALSE);
     gtk_widget_set_sensitive(lookup_widget(win_main, "album_genre"), FALSE);	// lnr
     gtk_widget_set_sensitive(lookup_widget(win_main, "genre_label"), FALSE);	// lnr
-    gtk_widget_set_sensitive(lookup_widget(win_main, "single_genre"), FALSE);	// lnr
     gtk_widget_set_sensitive(lookup_widget(win_main, "album_year"), FALSE);
 }
 
@@ -1317,7 +1305,6 @@ void enable_all_main_widgets(void)
     gtk_widget_set_sensitive(lookup_widget(win_main, "rip_button"), TRUE);
     gtk_widget_set_sensitive(lookup_widget(win_main, "album_genre"), TRUE);		// lnr
     gtk_widget_set_sensitive(lookup_widget(win_main, "genre_label"), TRUE);		// lnr
-    gtk_widget_set_sensitive(lookup_widget(win_main, "single_genre"), TRUE);	// lnr
     gtk_widget_set_sensitive(lookup_widget(win_main, "album_year"), TRUE);
 }
 
@@ -1438,7 +1425,7 @@ void enable_musepack_widgets(void)
 }
 
 const char* 
-GBLprogramName = "Asunder 2.9.1";
+GBLprogramName = "Asunder 2.9.2";
 
 static const char* 
 GBLauthors[2] = {
@@ -1467,6 +1454,9 @@ GBLauthors[2] = {
 "- Fixed race condition during abort\n"
 "- Improved completion percentage feedback\n"
 "- Added feature to make the artist and title columns resizable\n"
+"- Remove 'single genre' code that's been unused since 2010.\n"
+"- Added features to automatically fix some common mistakes in CDDB entries.\n"
+"- Fixed the wavpack and mpc encoders to include APEv2 metadata.\n"
 "(A few patches were mistakenly attributed to \"Gregory Montego\" and \"Gergory Margo\")\n"
 "\n"
 "Andreas Ronnquist\n"
@@ -1774,7 +1764,7 @@ GBLtranslators =
 "- sv (Swedish) translation of Asunder versions 0.8 - 1.9\n"
 "\n"
 "Andreas Ronnquist\n"
-"- sv (Swedish) translation of Asunder versions 2.2-2.7\n"
+"- sv (Swedish) translation of Asunder versions 2.2-2.9\n"
 "\n"
 "Savas Sen\n"
 "- tr (Turkish) translation of Asunder version 1.9\n"
@@ -1799,13 +1789,13 @@ GBLtranslators =
 static const char* 
 GBLcomments = 
 N_("An application to save tracks from an Audio CD \n"
-"as WAV, MP3, OGG, FLAC, Opus, Wavpack, Musepack, Monkey's Audio, and/or "
+"as WAV, MP3, OGG, FLAC, Wavpack, Opus, Musepack, Monkey's Audio, and/or "
 "AAC files.");
 
 static const char* 
 GBLcopyright = 
 "Copyright 2005 Eric Lathrop\n"
-"Copyright 2007 - 2017 Andrew Smith";
+"Copyright 2007 - 2018 Andrew Smith";
 
 static const char* 
 GBLwebsite = "http://littlesvr.ca/asunder/";
